
#include "itkAdditiveGaussianNoiseImageFilter.h"
#include "itkImageFileReader.h"
#include "itkImageFileWriter.h"

typedef itk::Image< unsigned char, 2 >                  ImageType;
typedef itk::ImageFileReader< ImageType >               ReaderType;
typedef itk::AdditiveGaussianNoiseImageFilter<
    ImageType >                                         NoisyFilterType;
typedef itk::ImageFileWriter< ImageType >               WriterType;

int main( int argc, char* argv[] )
{
    ReaderType::Pointer reader = ReaderType::New();
    NoisyFilterType::Pointer noisy = NoisyFilterType::New();
    WriterType::Pointer writer = WriterType::New();

    reader->SetFileName( argv[1] );
    noisy->SetInput( reader->GetOutput() );
    writer->SetInput( noisy->GetOutput() );
    writer->SetFileName( argv[2] );

    std::cout
        << "Filter Output: " << noisy << std::endl;
    noisy->GetOutput()->Print(std::cout );

    try
    {
        writer->Update();
    }
    catch ( itk::ExceptionObject & excep )
    {
        std::cerr << "Exception caught !" << std::endl;
        std::cerr << excep << std::endl;
    }

    return 0;
}
